@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,32 +10,37 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
+"""PyAMS_content.component.gallery.zmi.interfaces module
+
+This module defines interfaces which are used by gallery management interface.
+"""
+
 __docformat__ = 'restructuredtext'
 
-
-# import standard library
-
-# import interfaces
-
 from zope.interface import Interface
 from zope.schema import TextLine
 
-from pyams_content import _
-# import packages
 from pyams_file.schema import FileField
 
+from pyams_content import _
 
-class IGalleryContentsView(Interface):
-    """Marker interface for gallery contents view"""
+
+class IGalleryMediasView(Interface):
+    """Gallery medias view marker interface"""
 
 
 class IGalleryMediasAddFields(Interface):
-    """Gallery medias add fields"""
+    """Gallery medias add fields interface"""
 
     medias_data = FileField(title=_("Images or videos data"),
-                            description=_("You can upload a single file or choose to upload a whole ZIP archive"),
+                            description=_("You can upload a single file, or choose to upload "
+                                          "a whole ZIP archive"),
                             required=True)
 
     author = TextLine(title=_("Author"),
                       description=_("Name of document's author"),
-                      required=True)
+                      required=False)
+
+
+class IGalleryMediaThumbnailView(Interface):
+    """Gallery media thumbnail view marker interface"""
