@@ -1,5 +1,3 @@
-#
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,34 +8,23 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-__docformat__ = 'restructuredtext'
-
-
-# import standard library
-
-# import interfaces
+from pyams_content.component.keynumber import IKeyNumbersContainer
+from pyams_content.feature.navigation import IMenusContainer
+from pyams_i18n.schema import I18nTextField, I18nTextLineField
 from pyams_portal.interfaces import IPortletSettings
 
-# import packages
-from pyams_i18n.schema import I18nTextLineField, I18nTextField
-from zope.interface import Attribute, Interface
+__docformat__ = 'restructuredtext'
 
 from pyams_content import _
 
 
-class IKeyNumberPortletSettings(IPortletSettings):
-    """Key numbers portlet settings interface"""
-
+class IKeyNumbersPortletSettings(IPortletSettings, IKeyNumbersContainer):
+    """Key number portlet settings interface"""
+    
     title = I18nTextLineField(title=_("Title"),
-                              description=_("Portlet title"),
+                              description=_("Main component title"),
                               required=False)
-
-    teaser = I18nTextField(title=_("Teaser"),
-                           description=_("Short text displayed above key numbers"),
+    
+    header = I18nTextField(title=_("Header"),
+                           description=_("Short text to be displayed below title"),
                            required=False)
-
-    links = Attribute("Navigation links")
-
-
-class IKeyNumberPortletMenu(Interface):
-    """Key numbers portlet menu marker interface"""
