@@ -85,7 +85,7 @@ class IParagraphContainer(IOrderedContainer):
         """Get paragraphs matching given factories"""
 
     def get_visible_paragraphs(self, names=None, anchors_only=False, exclude_anchors=False,
-                               factories=None, limit=None):
+                               factories=None, excluded_factories=None, limit=None):
         """Get visible paragraphs matching given arguments"""
 
 
@@ -96,13 +96,12 @@ class IParagraphContainerTarget(IAttributeAnnotatable):
     """Paragraphs container marker interface"""
 
 
-PARAGRAPH_FACTORIES_VOCABULARY = 'pyams_content.paragraph.factories'
-
-
 #
 # Paragraph factory settings
 #
 
+PARAGRAPH_FACTORIES_VOCABULARY = 'pyams_content.paragraph.factories'
+
 PARAGRAPH_FACTORY_SETTINGS_KEY = 'pyams_content.paragraph.settings'
 
 
