@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,15 +10,22 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
+"""PyAMS_content.component.paragraph.zmi.interfaces module
+
+"""
+
 __docformat__ = 'restructuredtext'
 
 from zope.interface import Interface
 
-from pyams_form.interfaces.form import IInnerForm
 from pyams_viewlet.interfaces import IViewletManager
 
 
-class IParagraphContainerTable(Interface):
+class IParagraphContainerBaseTable(Interface):
+    """Paragraph container base table marker interface"""
+
+
+class IParagraphContainerFullTable(IParagraphContainerBaseTable):
     """Paragraph container table marker interface"""
 
 
@@ -26,13 +33,21 @@ class IParagraphContainerView(Interface):
     """Paragraph container view marker interface"""
 
 
-class IParagraphsParentForm(Interface):
-    """Paragraphs view parent form marker interface"""
+class IParagraphAddForm(Interface):
+    """Paragraph add form marker interface"""
+
+
+class IParagraphEditForm(Interface):
+    """Paragraph edit form marker interface"""
+
+
+class IInnerParagraphEditForm(Interface):
+    """Inner paragraph edit form marker interface"""
+
+
+class IParagraphRendererSettingsEditForm(Interface):
+    """Paragraph renderer settings edit form interface"""
 
 
 class IParagraphTitleToolbar(IViewletManager):
-    """Paragraph title toolbar viewlet manager"""
-
-
-class IParagraphInnerEditor(IInnerForm):
-    """Paragraph inner editor form interface"""
+    """Paragraph title toolbar viewlet manager interface"""
