@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2024 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,30 +10,27 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-from zope.interface import Attribute, Interface
+"""PyAMS_content.component.verbatim..portlet.interfaces module
 
+This module defines verbatim portlet interfaces.
+"""
+
+from pyams_content.component.verbatim.interfaces import IVerbatimContainer
 from pyams_i18n.schema import I18nTextField, I18nTextLineField
 from pyams_portal.interfaces import IPortletSettings
 
-
 __docformat__ = 'restructuredtext'
 
 from pyams_content import _
 
 
-class IVerbatimPortletSettings(IPortletSettings):
-    """Verbatims portlet settings interface"""
+class IVerbatimPortletSettings(IPortletSettings, IVerbatimContainer):
+    """Verbatim portlet settings interface"""
 
     title = I18nTextLineField(title=_("Title"),
-                              description=_("Portlet title"),
+                              description=_("Main component title"),
                               required=False)
 
-    teaser = I18nTextField(title=_("Teaser"),
-                           description=_("Short text displayed above verbatims"),
-                           required=False)
-
-    verbatims = Attribute("Verbatims list")
-
-
-class IVerbatimPortletMenu(Interface):
-    """Verbatims portlet menu marker interface"""
+    lead = I18nTextField(title=_("Leading text"),
+                         description=_("Short text to be displayed below title"),
+                         required=False)
