@@ -37,8 +37,11 @@ from pyams_content.root import ISiteRootToolsConfiguration
 from pyams_content.shared.alert.interfaces import IAlertManager
 from pyams_content.shared.common.interfaces import IWfSharedContent
 from pyams_content.shared.common.interfaces.types import IWfTypedSharedContent
+from pyams_content.shared.file.interfaces import IFileManager
 from pyams_content.shared.form.interfaces import IFormManager
+from pyams_content.shared.logo.interfaces import ILogoManager
 from pyams_content.shared.news.interfaces import INewsManager
+from pyams_content.shared.resource.interfaces import IResourceManager
 from pyams_content.shared.topic.interfaces import ITopicManager
 from pyams_content.shared.view.interfaces import IViewManager
 from pyams_security.index import PrincipalsRoleIndex
@@ -63,8 +66,11 @@ REQUIRED_TOOLS = (
     (IViewManager, 'views'),
     (IAlertManager, 'alerts'),
     (IFormManager, 'forms'),
+    (ILogoManager, 'logos'),
+    (IFileManager, 'files'),
     (INewsManager, 'news'),
-    (ITopicManager, 'topics')
+    (ITopicManager, 'topics'),
+    (IResourceManager, 'resources')
 )
 
 REQUIRED_INDEXES = [
