@@ -1,5 +1,3 @@
-#
-# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,16 +8,14 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-"""PyAMS_*** module
-
-"""
-
 from pyramid.httpexceptions import HTTPNotFound
 from pyramid.view import view_config
+
 from pyams_content.component.file import ProtectedFileView
 from pyams_content.shared.file import IWfFile
-from pyams_skin.layer import IPyAMSLayer
-
+from pyams_i18n.interfaces import II18n
+from pyams_layer.interfaces import IPyAMSLayer
+from pyams_utils.rest import http_error
 
 __docformat__ = 'restructuredtext'
 
@@ -27,8 +23,8 @@ __docformat__ = 'restructuredtext'
 @view_config(context=IWfFile, request_type=IPyAMSLayer)
 def render_file(request):
     """Shared file renderer"""
-    data = request.context.data
+    data = II18n(request.context).query_attribute('data', request=request)
     if data:
         request.context = data
         return ProtectedFileView(request)
-    raise HTTPNotFound
+    return http_error(request, HTTPNotFound)
