@@ -19,9 +19,10 @@ __docformat__ = 'restructuredtext'
 from pyramid.events import subscriber
 from zope.component.interfaces import ISite
 from zope.interface import implementer
-from zope.lifecycleevent import IObjectAddedEvent
+from zope.lifecycleevent.interfaces import IObjectAddedEvent
 
 from pyams_content.component.paragraph.interfaces import IParagraphFactorySettingsTarget
+from pyams_content.component.thesaurus.interfaces import IThemesManagerTarget
 from pyams_content.reference.pictogram.interfaces import IPictogramManagerTarget
 from pyams_content.shared.common.manager import SharedTool
 from pyams_content.shared.common.types import TypedSharedToolMixin
@@ -33,7 +34,8 @@ from pyams_utils.traversing import get_parent
 
 
 @factory_config(IFormManager)
-@implementer(ICaptchaManagerTarget, IParagraphFactorySettingsTarget, IPictogramManagerTarget)
+@implementer(ICaptchaManagerTarget, IParagraphFactorySettingsTarget, IThemesManagerTarget,
+             IPictogramManagerTarget)
 class FormManager(SharedTool, TypedSharedToolMixin):
     """Form manager class"""
 
