@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,35 +10,30 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-__docformat__ = 'restructuredtext'
+"""PyAMS_content.shared.news.interfaces module
 
-from zope.interface import Interface
+"""
 
-from pyams_content import _
 from pyams_content.shared.common.interfaces import ISharedContent, ISharedToolPortalContext, \
     IWfSharedContentPortalContext
 from pyams_sequence.interfaces import IInternalReferencesList
 
+__docformat__ = 'restructuredtext'
+
+from pyams_content import _
+
 
 NEWS_CONTENT_TYPE = 'news'
-NEWS_CONTENT_NAME = _("News topic")
+NEWS_CONTENT_NAME = _("News")
+
+
+class IWfNews(IWfSharedContentPortalContext, IInternalReferencesList):
+    """News interface"""
+
+
+class INews(ISharedContent):
+    """Workflow managed news interface"""
 
 
 class INewsManager(ISharedToolPortalContext):
     """News manager interface"""
-
-
-class INewsManagerFactory(Interface):
-    """News manager factory interface"""
-
-
-class IWfNewsEvent(IWfSharedContentPortalContext, IInternalReferencesList):
-    """News event interface"""
-
-
-class IWfNewsEventFactory(Interface):
-    """News event factory interface"""
-
-
-class INewsEvent(ISharedContent):
-    """Workflow managed news event interface"""
