@@ -1,5 +1,3 @@
-#
-# Copyright (c) 2008-2019 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +10,14 @@
 
 __docformat__ = 'restructuredtext'
 
-from z3c.form.interfaces import IObjectWidget
+from pyams_form.interfaces import INPUT_MODE
+from pyams_form.interfaces.widget import IObjectWidget
+from pyams_form.template import widget_layout_config
+from pyams_layer.interfaces import IFormLayer, IPyAMSLayer
+from pyams_template.template import layout_config
 
 
+@widget_layout_config(mode=INPUT_MODE,
+                      template='templates/age-range-input-layout.pt', layer=IPyAMSLayer)
 class IAgeRangeWidget(IObjectWidget):
     """Age range widget interface"""
