@@ -1,5 +1,3 @@
-#
-# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,36 +8,33 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-__docformat__ = 'restructuredtext'
-
 from zope.schema.fieldproperty import FieldProperty
 
-from pyams_content.shared.site.portlet.interfaces import ISiteContainerSummaryPortletSettings
+from pyams_content.shared.site.portlet.interfaces import ISiteContainerSummaryPortletSettings, \
+    SITE_CONTAINER_SUMMARY_PORTLET_NAME
 from pyams_portal.portlet import Portlet, PortletSettings, portlet_config
 from pyams_utils.factory import factory_config
-from pyams_utils.interfaces import VIEW_PERMISSION
+
+__docformat__ = 'restructuredtext'
 
 from pyams_content import _
 
 
-SITE_CONTAINER_SUMMARY_PORTLET_NAME = 'pyams_content.site.summary'
-
-
 @factory_config(provided=ISiteContainerSummaryPortletSettings)
 class SiteContainerSummaryPortletSettings(PortletSettings):
     """Site container summary portlet settings"""
-
+    
     title = FieldProperty(ISiteContainerSummaryPortletSettings['title'])
     button_title = FieldProperty(ISiteContainerSummaryPortletSettings['button_title'])
-
-
-@portlet_config(permission=VIEW_PERMISSION)
+    
+    
+@portlet_config(permission=None)
 class SiteContainerSummaryPortlet(Portlet):
     """Site container summary portlet"""
-
+    
     name = SITE_CONTAINER_SUMMARY_PORTLET_NAME
-    label = _("Site summary")
-
-    toolbar_css_class = 'fa fa-fw fa-2x fa-list-alt'
-
+    label = _("Site container summary")
+    
     settings_factory = ISiteContainerSummaryPortletSettings
+    toolbar_css_class = 'far fa-list-alt'
+    
\ No newline at end of file
