@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,18 +10,23 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
+"""PyAMS_content.shared.site.zmi.widget.interfaces module
+
+"""
+
 __docformat__ = 'restructuredtext'
 
-
-# import standard library
-
-# import interfaces
-from z3c.form.interfaces import ITextWidget
-
-# import packages
 from zope.interface import Attribute
 
+from pyams_form.interfaces import INPUT_MODE
+from pyams_form.interfaces.widget import ITextWidget
+from pyams_form.template import widget_template_config
+from pyams_zmi.interfaces import IAdminLayer
 
+
+@widget_template_config(mode=INPUT_MODE,
+                        template='templates/folder-select-input.pt',
+                        layer=IAdminLayer)
 class ISiteManagerFoldersSelectorWidget(ITextWidget):
     """Site manager folders selector widget interface"""
 
