@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
+# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -10,15 +10,17 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-from zope.interface import Interface
+"""PyAMS_*** module
+
+"""
+
 from zope.schema import Choice
 
 from pyams_content.shared.common.interfaces import ISharedContent, ISharedToolPortalContext, \
     IWfSharedContentPortalContext
-from pyams_content.shared.common.interfaces.types import DATA_TYPES_VOCABULARY
+from pyams_content.shared.common.interfaces.types import VISIBLE_DATA_TYPES_VOCABULARY
 from pyams_sequence.interfaces import IInternalReferencesList
 
-
 __docformat__ = 'restructuredtext'
 
 from pyams_content import _
@@ -28,26 +30,18 @@ TOPIC_CONTENT_TYPE = 'topic'
 TOPIC_CONTENT_NAME = _("Topic")
 
 
-class ITopicManager(ISharedToolPortalContext):
-    """Topic manager interface"""
-
-
-class ITopicManagerFactory(Interface):
-    """Topic manager factory interface"""
-
-
 class IWfTopic(IWfSharedContentPortalContext, IInternalReferencesList):
     """Topic interface"""
 
     data_type = Choice(title=_("Data type"),
                        description=_("Type of content data"),
                        required=False,
-                       vocabulary=DATA_TYPES_VOCABULARY)
-
-
-class IWfTopicFactory(Interface):
-    """Topic parent interface"""
+                       vocabulary=VISIBLE_DATA_TYPES_VOCABULARY)
 
 
 class ITopic(ISharedContent):
     """Workflow managed topic interface"""
+
+
+class ITopicManager(ISharedToolPortalContext):
+    """Topic manager interface"""
