@@ -54,6 +54,8 @@ class ContentPublishingTask(Task):
 
     settings_view_name = None
     principal_id = INTERNAL_USER_ID
+    
+    is_zodb_task = True
 
     def __init__(self, oid, transition_id):
         super().__init__()
@@ -91,6 +93,8 @@ class ContentArchivingTask(Task):
 
     settings_view_name = None
     principal_id = INTERNAL_USER_ID
+    
+    is_zodb_task = True
 
     def __init__(self, oid):
         super().__init__()
@@ -123,9 +127,9 @@ def handle_scheduler_start(event):
     """Check for scheduler tasks
 
     Workflow management tasks are typically automatically deleted after their execution.
-    If tasks with passed execution date are still present in the scheduler, this is generally
-    because scheduler was stopped at task execution time; so tasks which where not run are
-    re-scheduled at process startup in a very near future...
+    If tasks with a passed execution date are still present in the scheduler, this is generally
+    because the scheduler was stopped at task execution time; so tasks which where not run are
+    re-scheduled at process startup in the very near future...
     """
     with ZODBConnection() as root:
         registry = get_pyramid_registry()
